from cmath import inf
import copy
import time
import math
from random import Random, shuffle
import copy

#import warnings

from .solution import Solution
#warnings.filterwarnings("ignore")

class Test:

    def __init__(self, mess):
        self.message = mess
        
        
    def print(self):
        print(self.message)




import copy
from math import e, inf
import math

class Solution:

    math_error_count = 0
    fit_calls = 0
    fit_fails = 0

    @classmethod
    def clearStats(cls):
        cls.math_error_count=0
        cls.fit_fails = 0
        cls.fit_calls=0

    def __init__(self, factors, complexity_penalty):
        # factors are basically subexpressions that enter linear combination, e.g. 2*x+3y*sin(x*y) --> factors = [2x, 3y*sin(x*y)]
        self.factors =  copy.deepcopy(factors)
        self.complexity_penalty = complexity_penalty

    def __str__(self) -> str:
        return "+".join([str(x) for x in self.factors])



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='test_27_11a',
    version='0.2',
    description='Test: work with PyPi',
    long_description= long_description,
    long_description_content_type  = "text/markdown",
    author='Marko Đukanović',
    author_email='marko.djukanovic@pmf.unibl.org',
    url='https://github.com/markodjukanovic90/',
    packages = find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License", 
        "Operating System :: OS Independent"
    ],
    python_requires= ">=3.6",
    py_modules=["test_27_11a"],
    package_dir = {'test-27-11':'test_27_11'}, 
    install_requires=[ "sympy" ],
)
